@@ -87,8 +87,8 @@ module w_base_module
       do j=1,jm/2
          y_Lat(jm/2+j)   =  asin(y(j,1))        ! ٺɸ
          y_Lat(jm/2-j+1) = -asin(y(j,1))        ! ٺɸ
-         y_Lat_Weight(jm/2+j)   = y(j,2)        ! ٽŤ(Gauss grid)
-         y_Lat_Weight(jm/2-j+1) = y(j,2)        ! ٽŤ(Gauss grid)
+         y_Lat_Weight(jm/2+j)   = 2*y(j,2)      ! ٽŤ(Gauss grid)
+         y_Lat_Weight(jm/2-j+1) = 2*y(j,2)      ! ٽŤ(Gauss grid)
       enddo
 
       do j=1,jm
