@@ -35,6 +35,8 @@ module w_deriv_module
   public w_DivLon_xy, w_DivLat_xy             ! ȯʬ
   public w_Div_xy_xy                          ! ȯʬ
   public w_Jacobian_w_w                       ! 䥳ӥ
+  public xy_GradLambda_w, xy_GradMu_w         ! ۷ʬ(,̺ɸ)
+  public w_DivLambda_xy, w_DivMu_xy           ! ȯʬ(,̺ɸ)
 
   public rn, irm                              ! ץ饷/ʬ黻
 
@@ -146,4 +148,38 @@ module w_deriv_module
            it,t,y,ip2,p2,r2,ip3,p3,r3,ia,a,q,ws,ww)
     end function w_Jacobian_w_w
 
+  !--------------- ʬ׻ (,̺ɸ) -----------------
+    function xy_GradLambda_w(w_data) ! ڥȥ˺Ѥ۷ʬ
+                                     ! /ߦ
+      real(8)              :: xy_GradLambda_w(im,jm)
+      real(8), intent(in)  :: w_data((nm+1)*(nm+1))
+
+      xy_GradLambda_w = xy_w(w_data,ipow=0,iflag=-1)
+    end function xy_GradLambda_w
+
+    function xy_GradMu_w(w_data) ! ڥȥ˺Ѥ۷ʬ
+                                  ! (1-^2)/ߦ  (=sin)
+      real(8)              :: xy_GradMu_w(im,jm)
+      real(8), intent(in)  :: w_data((nm+1)*(nm+1))
+
+      xy_GradMu_w = xy_w(w_data,ipow=0,iflag=1)
+    end function xy_GradMu_w
+
+    function w_DivLambda_xy(xy_data) ! ʻҤ˺Ѥȯʬ
+                                     ! 1/(1-^2)/ߦ
+      real(8)              :: w_DivLambda_xy((nm+1)*(nm+1))
+      real(8), intent(in)  :: xy_data(im,jm)
+
+      w_DivLambda_xy = w_xy(xy_data,ipow=2,iflag=-1)
+    end function w_DivLambda_xy
+
+    function w_DivMu_xy(xy_data)   ! ʻҤ˺Ѥȯʬ
+                                    ! /ߦ
+
+      real(8)              :: w_DivMu_xy((nm+1)*(nm+1))
+      real(8), intent(in)  :: xy_data(im,jm)
+
+      w_DivMu_xy = w_xy(xy_data,ipow=2,iflag=1)
+    end function w_DivMu_xy
+
   end module w_deriv_module
